@@ -49,6 +49,7 @@ static char **opt_endoflife_rebase;
 static char **opt_endoflife_rebase_new;
 static char *opt_timestamp;
 static char **opt_extra_collection_ids;
+static int opt_token_type = -1;
 
 static GOptionEntry options[] = {
   { "src-repo", 0, 0, G_OPTION_ARG_STRING, &opt_src_repo, N_("Source repo dir"), N_("SRC-REPO") },
@@ -64,6 +65,7 @@ static GOptionEntry options[] = {
   { "gpg-homedir", 0, 0, G_OPTION_ARG_STRING, &opt_gpg_homedir, N_("GPG Homedir to use when looking for keyrings"), N_("HOMEDIR") },
   { "end-of-life", 0, 0, G_OPTION_ARG_STRING, &opt_endoflife, N_("Mark build as end-of-life"), N_("REASON") },
   { "end-of-life-rebase", 0, 0, G_OPTION_ARG_STRING_ARRAY, &opt_endoflife_rebase, N_("Mark refs matching the OLDID prefix as end-of-life, to be replaced with the given NEWID"), N_("OLDID=NEWID") },
+  { "token-type", 0, 0, G_OPTION_ARG_INT, &opt_token_type, N_("Set type of token needed to install this commit"), N_("VAL") },
   { "timestamp", 0, 0, G_OPTION_ARG_STRING, &opt_timestamp, N_("Override the timestamp of the commit (NOW for current time)"), N_("TIMESTAMP") },
   { "disable-fsync", 0, 0, G_OPTION_ARG_NONE, &opt_disable_fsync, "Do not invoke fsync()", NULL },
   { NULL }
@@ -263,7 +265,7 @@ flatpak_builtin_build_commit_from (int argc, char **argv, GCancellable *cancella
     return usage_error (context, _("If --src-ref is specified, exactly one destination ref must be specified"), error);
 
   if (opt_src_repo == NULL && opt_src_ref == NULL)
-    return flatpak_fail (error, _("Either --src-repo or --src-ref must be specified."));
+    return flatpak_fail (error, _("Either --src-repo or --src-ref must be specified"));
 
   /* Always create a commit if we're eol:ing, even though the app is the same */
   if (opt_endoflife != NULL || opt_endoflife_rebase != NULL)
@@ -381,7 +383,7 @@ flatpak_builtin_build_commit_from (int argc, char **argv, GCancellable *cancella
     {
       OstreeRepoPullFlags pullflags = 0;
       GVariantBuilder builder;
-      g_autoptr(OstreeAsyncProgress) progress = NULL;
+      g_autoptr(OstreeAsyncProgressFinish) progress = NULL;
       g_auto(GLnxConsoleRef) console = { 0, };
       g_autoptr(GVariant) options = NULL;
       gboolean res;
@@ -408,9 +410,6 @@ flatpak_builtin_build_commit_from (int argc, char **argv, GCancellable *cancella
                                            progress,
                                            cancellable, error);
 
-      if (progress)
-        ostree_async_progress_finish (progress);
-
       if (!res)
         return FALSE;
     }
@@ -464,7 +463,7 @@ flatpak_builtin_build_commit_from (int argc, char **argv, GCancellable *cancella
         return FALSE;
 
       if (src_commit_state & OSTREE_REPO_COMMIT_STATE_PARTIAL)
-        return flatpak_fail (error, _("Can't commit from partial source commit."));
+        return flatpak_fail (error, _("Can't commit from partial source commit"));
 
       /* Don't create a new commit if this is the same tree */
       if (!opt_force && dst_parent_root != NULL && g_file_equal (dst_parent_root, src_ref_root))
@@ -573,6 +572,9 @@ flatpak_builtin_build_commit_from (int argc, char **argv, GCancellable *cancella
               strcmp (key, OSTREE_COMMIT_META_KEY_ENDOFLIFE_REBASE) == 0)
             continue;
 
+          if (opt_token_type >= 0 && strcmp (key, "xa.token-type") == 0)
+            continue;
+
           g_variant_builder_add_value (&metadata_builder, child);
         }
 
@@ -600,6 +602,10 @@ flatpak_builtin_build_commit_from (int argc, char **argv, GCancellable *cancella
             }
         }
 
+      if (opt_token_type >= 0)
+        g_variant_builder_add (&metadata_builder, "{sv}", "xa.token-type",
+                               g_variant_new_int32 (opt_token_type));
+
       timestamp = ostree_commit_get_timestamp (src_commitv);
       if (opt_timestamp)
         timestamp = ts.tv_sec;
