@@ -51,6 +51,7 @@ static char *opt_timestamp = NULL;
 static char *opt_endoflife;
 static char *opt_endoflife_rebase;
 static char *opt_collection_id = NULL;
+static int opt_token_type = -1;
 
 static GOptionEntry options[] = {
   { "subject", 's', 0, G_OPTION_ARG_STRING, &opt_subject, N_("One line subject"), N_("SUBJECT") },
@@ -67,6 +68,7 @@ static GOptionEntry options[] = {
   { "gpg-homedir", 0, 0, G_OPTION_ARG_STRING, &opt_gpg_homedir, N_("GPG Homedir to use when looking for keyrings"), N_("HOMEDIR") },
   { "end-of-life", 0, 0, G_OPTION_ARG_STRING, &opt_endoflife, N_("Mark build as end-of-life"), N_("REASON") },
   { "end-of-life-rebase", 0, 0, G_OPTION_ARG_STRING, &opt_endoflife_rebase, N_("Mark build as end-of-life, to be replaced with the given ID"), N_("ID") },
+  { "token-type", 0, 0, G_OPTION_ARG_INT, &opt_token_type, N_("Set type of token needed to install this commit"), N_("VAL") },
   { "timestamp", 0, 0, G_OPTION_ARG_STRING, &opt_timestamp, N_("Override the timestamp of the commit"), N_("TIMESTAMP") },
   { "collection-id", 0, 0, G_OPTION_ARG_STRING, &opt_collection_id, N_("Collection ID"), "COLLECTION-ID" },
   { "disable-fsync", 0, 0, G_OPTION_ARG_NONE, &opt_disable_fsync, "Do not invoke fsync()", NULL },
@@ -1031,6 +1033,10 @@ flatpak_builtin_build_export (int argc, char **argv, GCancellable *cancellable,
                                    g_variant_new_string (rebased_ref));
     }
 
+  if (opt_token_type >= 0)
+    g_variant_dict_insert_value (&metadata_dict, "xa.token-type",
+                                 g_variant_new_int32 (opt_token_type));
+
   metadata_dict_v = g_variant_ref_sink (g_variant_dict_end (&metadata_dict));
 
   /* The timestamp is used for the commit metadata and AppStream data */
