@@ -60,10 +60,11 @@ import_oci (OstreeRepo *repo, GFile *file,
   const char *oci_digest;
   g_autoptr(FlatpakOciRegistry) registry = NULL;
   g_autoptr(FlatpakOciVersioned) versioned = NULL;
+  g_autoptr(FlatpakOciImage) image_config = NULL;
   FlatpakOciManifest *manifest = NULL;
   g_autoptr(FlatpakOciIndex) index = NULL;
   const FlatpakOciManifestDescriptor *desc;
-  GHashTable *annotations;
+  GHashTable *labels;
 
   dir_uri = g_file_get_uri (file);
   registry = flatpak_oci_registry_new (dir_uri, FALSE, -1, cancellable, error);
@@ -103,11 +104,16 @@ import_oci (OstreeRepo *repo, GFile *file,
 
   manifest = FLATPAK_OCI_MANIFEST (versioned);
 
-  annotations = flatpak_oci_manifest_get_annotations (manifest);
-  if (annotations)
-    flatpak_oci_parse_commit_annotations (annotations, NULL, NULL, NULL,
-                                          &target_ref, NULL, NULL, NULL);
+  image_config = flatpak_oci_registry_load_image_config (registry, NULL,
+                                                         manifest->config.digest,
+                                                         NULL, cancellable, error);
+  if (image_config == NULL)
+    return FALSE;
 
+  labels = flatpak_oci_image_get_labels (image_config);
+  if (labels)
+    flatpak_oci_parse_commit_labels (labels, NULL, NULL, NULL,
+                                     &target_ref, NULL, NULL, NULL);
   if (target_ref == NULL)
     {
       g_set_error (error, G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED,
@@ -115,7 +121,7 @@ import_oci (OstreeRepo *repo, GFile *file,
       return NULL;
     }
 
-  commit_checksum = flatpak_pull_from_oci (repo, registry, NULL, oci_digest, manifest,
+  commit_checksum = flatpak_pull_from_oci (repo, registry, NULL, oci_digest, manifest, image_config,
                                            NULL, target_ref, NULL, NULL, cancellable, error);
   if (commit_checksum == NULL)
     return NULL;
