@@ -47,11 +47,13 @@ typedef enum {
   FLATPAK_RUN_FLAG_CANBUS            = (1 << 17),
   FLATPAK_RUN_FLAG_DO_NOT_REAP        = (1 << 18),
   FLATPAK_RUN_FLAG_NO_PROC            = (1 << 19),
+  FLATPAK_RUN_FLAG_PARENT_EXPOSE_PIDS = (1 << 20),
 } FlatpakRunFlags;
 
 typedef struct FlatpakDir          FlatpakDir;
 typedef struct FlatpakDeploy       FlatpakDeploy;
 typedef struct FlatpakOciRegistry  FlatpakOciRegistry;
 typedef struct _FlatpakOciManifest FlatpakOciManifest;
+typedef struct _FlatpakOciImage    FlatpakOciImage;
 
 #endif /* __FLATPAK_COMMON_TYPES_H__ */
