@@ -42,12 +42,14 @@ typedef enum {
   FLATPAK_CONTEXT_SOCKET_FALLBACK_X11 = 1 << 5, /* For backwards compat, also set SOCKET_X11 */
   FLATPAK_CONTEXT_SOCKET_SSH_AUTH    = 1 << 6,
   FLATPAK_CONTEXT_SOCKET_PCSC        = 1 << 7,
+  FLATPAK_CONTEXT_SOCKET_CUPS        = 1 << 8,
 } FlatpakContextSockets;
 
 typedef enum {
   FLATPAK_CONTEXT_DEVICE_DRI         = 1 << 0,
   FLATPAK_CONTEXT_DEVICE_ALL         = 1 << 1,
   FLATPAK_CONTEXT_DEVICE_KVM         = 1 << 2,
+  FLATPAK_CONTEXT_DEVICE_SHM         = 1 << 3,
 } FlatpakContextDevices;
 
 typedef enum {
@@ -106,10 +108,13 @@ FlatpakRunFlags flatpak_context_get_run_flags (FlatpakContext *context);
 void           flatpak_context_add_bus_filters (FlatpakContext *context,
                                                 const char     *app_id,
                                                 gboolean        session_bus,
+                                                gboolean        sandboxed,
                                                 FlatpakBwrap   *bwrap);
 
 gboolean       flatpak_context_get_needs_session_bus_proxy (FlatpakContext *context);
 gboolean       flatpak_context_get_needs_system_bus_proxy (FlatpakContext *context);
+gboolean       flatpak_context_adds_permissions (FlatpakContext *old_context,
+                                                 FlatpakContext *new_context);
 
 void           flatpak_context_reset_permissions (FlatpakContext *context);
 void           flatpak_context_reset_non_permissions (FlatpakContext *context);
