@@ -205,6 +205,12 @@ flatpak_oci_registry_init (FlatpakOciRegistry *self)
   self->tmp_dfd = -1;
 }
 
+gboolean
+flatpak_oci_registry_is_local (FlatpakOciRegistry *self)
+{
+  return self->dfd != -1;
+}
+
 const char *
 flatpak_oci_registry_get_uri (FlatpakOciRegistry *self)
 {
@@ -217,8 +223,15 @@ flatpak_oci_registry_set_token (FlatpakOciRegistry *self,
 {
   g_free (self->token);
   self->token = g_strdup (token);
+
+  if (self->token)
+    (void)glnx_file_replace_contents_at (self->dfd, ".token",
+                                         (guchar *)self->token,
+                                         strlen (self->token),
+                                         0, NULL, NULL);
 }
 
+
 FlatpakOciRegistry *
 flatpak_oci_registry_new (const char   *uri,
                           gboolean      for_write,
@@ -409,6 +422,7 @@ flatpak_oci_registry_ensure_local (FlatpakOciRegistry *self,
   int dfd;
   g_autoptr(GError) local_error = NULL;
   g_autoptr(GBytes) oci_layout_bytes = NULL;
+  g_autoptr(GBytes) token_bytes = NULL;
   gboolean not_json;
 
   if (self->dfd != -1)
@@ -470,6 +484,13 @@ flatpak_oci_registry_ensure_local (FlatpakOciRegistry *self,
   else if (!verify_oci_version (oci_layout_bytes, &not_json, cancellable, error))
     return FALSE;
 
+  if (self->dfd != -1)
+    {
+      token_bytes = local_load_file (self->dfd, ".token", cancellable, NULL);
+      if (token_bytes != NULL)
+        self->token = g_strndup (g_bytes_get_data (token_bytes, NULL), g_bytes_get_size (token_bytes));
+    }
+
   if (self->dfd == -1 && local_dfd != -1)
     self->dfd = glnx_steal_fd (&local_dfd);
 
@@ -1015,6 +1036,9 @@ flatpak_oci_registry_get_token (FlatpakOciRegistry *self,
 
   msg = soup_message_new_from_uri ("HEAD", uri);
 
+  soup_message_headers_replace (msg->request_headers, "Accept",
+                                FLATPAK_OCI_MEDIA_TYPE_IMAGE_MANIFEST ", " FLATPAK_DOCKER_MEDIA_TYPE_IMAGE_MANIFEST2);
+
   stream = soup_session_send (self->soup_session, msg, NULL, error);
   if (stream == NULL)
     return NULL;
