@@ -1,5 +1,5 @@
 /*
- * Copyright © 2014 Red Hat, Inc
+ * Copyright © 2014-2019 Red Hat, Inc
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -20,6 +20,7 @@
 
 #include "config.h"
 
+#include <errno.h>
 #include <locale.h>
 #include <stdlib.h>
 #include <string.h>
@@ -28,7 +29,12 @@
 #include <gio/gio.h>
 #include <gio/gunixfdlist.h>
 #include "flatpak-dbus-generated.h"
-#include "flatpak-utils-private.h"
+#include "flatpak-utils-base-private.h"
+
+typedef enum {
+  FLATPAK_HOST_COMMAND_FLAGS_CLEAR_ENV = 1 << 0,
+  FLATPAK_HOST_COMMAND_FLAGS_WATCH_BUS = 1 << 1,
+} FlatpakHostCommandFlags;
 
 static char *monitor_dir;
 static char *p11_kit_server_socket_path;
@@ -195,6 +201,7 @@ child_setup_func (gpointer user_data)
 static gboolean
 handle_host_command (FlatpakDevelopment    *object,
                      GDBusMethodInvocation *invocation,
+                     GUnixFDList           *fd_list,
                      const gchar           *arg_cwd_path,
                      const gchar *const    *arg_argv,
                      GVariant              *arg_fds,
@@ -202,8 +209,6 @@ handle_host_command (FlatpakDevelopment    *object,
                      guint                  flags)
 {
   g_autoptr(GError) error = NULL;
-  GDBusMessage *message = g_dbus_method_invocation_get_message (invocation);
-  GUnixFDList *fd_list = g_dbus_message_get_unix_fd_list (message);
   ChildSetupData child_setup_data = { NULL };
   GPid pid;
   PidData *pid_data;
@@ -356,7 +361,7 @@ handle_host_command (FlatpakDevelopment    *object,
                         pid_data);
 
 
-  flatpak_development_complete_host_command (object, invocation,
+  flatpak_development_complete_host_command (object, invocation, NULL,
                                              pid_data->pid);
   return TRUE;
 }
