@@ -25,6 +25,7 @@ set -euo pipefail
 . $(dirname $0)/libtest.sh
 
 skip_without_bwrap
+skip_revokefs_without_fuse
 
 echo "1..3"
 
@@ -74,7 +75,7 @@ assert_file_has_content ${FL_DIR}/repo/config '^gpg-verify-summary=false$'
 assert_not_file_has_content ${FL_DIR}/repo/config '^gpg-verify-summary=true$'
 assert_file_has_content ${FL_DIR}/repo/config '^gpg-verify=true$'
 assert_not_file_has_content ${FL_DIR}/repo/config '^gpg-verify=false$'
-assert_file_has_content ${FL_DIR}/repo/config '^collection-id=org.test.Collection$'
+assert_file_has_content ${FL_DIR}/repo/config '^collection-id=org\.test\.Collection$'
 
 echo "ok 2 update repo config to deploy collection ID"
 
@@ -89,7 +90,7 @@ echo "ok 2 update repo config to deploy collection ID"
 ostree --repo=repos/test summary --update --add-metadata="ostree.deploy-collection-id='net.malicious.NewCollection'"
 ${FLATPAK} ${U} update org.test.App master
 
-assert_file_has_content ${FL_DIR}/repo/config '^collection-id=org.test.Collection$'
-assert_not_file_has_content ${FL_DIR}/repo/config '^collection-id=net.malicious.NewCollection$'
+assert_file_has_content ${FL_DIR}/repo/config '^collection-id=org\.test\.Collection$'
+assert_not_file_has_content ${FL_DIR}/repo/config '^collection-id=net\.malicious\.NewCollection$'
 
 echo "ok 3 update repo config with different collection ID"
